@oazmi/kitchensink - v0.10.1
    Preparing search index...

    Interface SimpleImageData

    represents an ImageData with optional color space information.

    interface SimpleImageData {
        data: Uint8Array<ArrayBufferLike> | Uint8ClampedArray<ArrayBufferLike>;
        colorSpace?: PredefinedColorSpace;
        height: number;
        width: number;
    }

    Hierarchy

    • Omit<ImageData, "colorSpace" | "data">
      • SimpleImageData
    Index

    Properties

    data: Uint8Array<ArrayBufferLike> | Uint8ClampedArray<ArrayBufferLike>
    colorSpace?: PredefinedColorSpace
    height: number

    The readonly ImageData.height property returns the number of rows in the ImageData object.

    MDN Reference

    width: number

    The readonly ImageData.width property returns the number of pixels per row in the ImageData object.

    MDN Reference