represents an ImageData with optional color space information.
ImageData
Optional
Readonly
The readonly ImageData.height property returns the number of rows in the ImageData object.
ImageData.height
MDN Reference
The readonly ImageData.width property returns the number of pixels per row in the ImageData object.
ImageData.width
represents an
ImageDatawith optional color space information.